<?php

namespace Assetdocs\Depart\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Form;
use Assetdocs\Depart\Http\Requests\DepartAdminWebRequest;
use Assetdocs\Depart\Interfaces\DepartRepositoryInterface;
use Assetdocs\Depart\Models\Depart;

/**
 * Admin web controller class.
 */
class DepartAdminController extends BaseController
{
    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'admin.web';

    /**
     * Initialize depart controller.
     *
     * @param type DepartRepositoryInterface $depart
     *
     * @return type
     */
    public function __construct(DepartRepositoryInterface $depart)
    {
        $this->middleware('web');
        $this->middleware('auth:admin.web');
        $this->setupTheme(config('theme.themes.admin.theme'), config('theme.themes.admin.layout'));

        $this->repository = $depart;
        parent::__construct();
    }

    /**
     * Display a list of depart.
     *
     * @return Response
     */
    public function index(DepartAdminWebRequest $request)
    {
        $pageLimit = $request->input('pageLimit');
        if ($request->wantsJson()) {
            $departs  = $this->repository
            ->pushCriteria(new \Assetdocs\Depart\Repositories\Criteria\DepartAdminCriteria())
                ->setPresenter('\\Assetdocs\\Depart\\Repositories\\Presenter\\DepartListPresenter')
                ->scopeQuery(function ($query) {
                    return $query->orderBy('id', 'DESC');
                })->paginate($pageLimit);

            $departs['recordsTotal']    = $departs['meta']['pagination']['total'];
            $departs['recordsFiltered'] = $departs['meta']['pagination']['total'];
            $departs['request']         = $request->all();
            return response()->json($departs, 200);

        }

        $this   ->theme->prependTitle(trans('depart::depart.names').' :: ');
        return $this->theme->of('depart::admin.depart.index')->render();
    }

    /**
     * Display depart.
     *
     * @param Request $request
     * @param Model   $depart
     *
     * @return Response
     */
    public function show(DepartAdminWebRequest $request, Depart $depart)
    {
        if (!$depart->exists) {
            return response()->view('depart::admin.depart.new', compact('depart'));
        }

        Form::populate($depart);
        return response()->view('depart::admin.depart.show', compact('depart'));
    }

    /**
     * Show the form for creating a new depart.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(DepartAdminWebRequest $request)
    {

        $depart = $this->repository->newInstance([]);

        Form::populate($depart);

        return response()->view('depart::admin.depart.create', compact('depart'));

    }

    /**
     * Create new depart.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(DepartAdminWebRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.web');
            $depart          = $this->repository->create($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('depart::depart.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/depart/depart/'.$depart->getRouteKey())
            ], 201);


        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
            ], 400);
        }
    }

    /**
     * Show depart for editing.
     *
     * @param Request $request
     * @param Model   $depart
     *
     * @return Response
     */
    public function edit(DepartAdminWebRequest $request, Depart $depart)
    {
        Form::populate($depart);
        return  response()->view('depart::admin.depart.edit', compact('depart'));
    }

    /**
     * Update the depart.
     *
     * @param Request $request
     * @param Model   $depart
     *
     * @return Response
     */
    public function update(DepartAdminWebRequest $request, Depart $depart)
    {
        try {

            $attributes = $request->all();

            $depart->update($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('depart::depart.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/depart/depart/'.$depart->getRouteKey())
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/depart/depart/'.$depart->getRouteKey()),
            ], 400);

        }
    }

    /**
     * Remove the depart.
     *
     * @param Model   $depart
     *
     * @return Response
     */
    public function destroy(DepartAdminWebRequest $request, Depart $depart)
    {

        try {

            $t = $depart->delete();

            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('depart::depart.name')]),
                'code'     => 202,
                'redirect' => trans_url('/admin/depart/depart/0'),
            ], 202);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/depart/depart/'.$depart->getRouteKey()),
            ], 400);
        }
    }
}
