<?php

namespace Assetdocs\Depart\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Depart\Http\Requests\DepartUserApiRequest;
use Assetdocs\Depart\Interfaces\DepartRepositoryInterface;
use Assetdocs\Depart\Models\Depart;

/**
 * User API controller class.
 */
class DepartUserApiController extends BaseController
{

    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'api';

    /**
     * Initialize depart controller.
     *
     * @param type DepartRepositoryInterface $depart
     *
     * @return type
     */
    public function __construct(DepartRepositoryInterface $depart)
    {
        $this->middleware('api');
        $this->middleware('jwt.auth:api');
        $this->setupTheme(config('theme.themes.user.theme'), config('theme.themes.user.layout'));

        $this->repository = $depart;
        parent::__construct();
    }

    /**
     * Display a list of depart.
     *
     * @return json
     */
    public function index(DepartUserApiRequest $request)
    {
        $departs  = $this->repository
            ->pushCriteria(new \Lavalite\Depart\Repositories\Criteria\DepartUserCriteria())
            ->setPresenter('\\Assetdocs\\Depart\\Repositories\\Presenter\\DepartListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $departs['code'] = 2000;
        return response()->json($departs) 
            ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display depart.
     *
     * @param Request $request
     * @param Model   Depart
     *
     * @return Json
     */
    public function show(DepartUserApiRequest $request, Depart $depart)
    {

        if ($depart->exists) {
            $depart         = $depart->presenter();
            $depart['code'] = 2001;
            return response()->json($depart)
                ->setStatusCode(200, 'SHOW_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }

    /**
     * Show the form for creating a new depart.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(DepartUserApiRequest $request, Depart $depart)
    {
        $depart         = $depart->presenter();
        $depart['code'] = 2002;
        return response()->json($depart)
            ->setStatusCode(200, 'CREATE_SUCCESS');
    }

    /**
     * Create new depart.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(DepartUserApiRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $depart          = $this->repository->create($attributes);
            $depart          = $depart->presenter();
            $depart['code']  = 2004;

            return response()->json($depart)
                ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message' => $e->getMessage(),
                'code'    => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }

    }

    /**
     * Show depart for editing.
     *
     * @param Request $request
     * @param Model   $depart
     *
     * @return json
     */
    public function edit(DepartUserApiRequest $request, Depart $depart)
    {
        if ($depart->exists) {
            $depart         = $depart->presenter();
            $depart['code'] = 2003;
            return response()-> json($depart)
                ->setStatusCode(200, 'EDIT_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }
    }

    /**
     * Update the depart.
     *
     * @param Request $request
     * @param Model   $depart
     *
     * @return json
     */
    public function update(DepartUserApiRequest $request, Depart $depart)
    {
        try {

            $attributes = $request->all();

            $depart->update($attributes);
            $depart         = $depart->presenter();
            $depart['code'] = 2005;

            return response()->json($depart)
                ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the depart.
     *
     * @param Request $request
     * @param Model   $depart
     *
     * @return json
     */
    public function destroy(DepartUserApiRequest $request, Depart $depart)
    {

        try {

            $t = $depart->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('depart::depart.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
